@@ -9,8 +9,7 @@ from core_main_app.components.template.models import Template
 
 
 class Type(Template):
-    """Type class.
-    """
+    """Type class."""
 
     is_complex = fields.BooleanField(blank=False)
 
