@@ -1,7 +1,9 @@
-from django.conf.urls import url, include
+from django.conf.urls import include
 from django.contrib import admin
+from django.urls import re_path
+
 from core_composer_app import urls as core_composer_app_urls
 
 urlpatterns = [
-    url(r'^admin/', include(admin.site.urls)),
+    re_path(r"^admin/", include(admin.site.urls)),
 ] + core_composer_app_urls.urlpatterns
